# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`restic`](#restic): Module to manage restic repositories via systemd service/timer.

#### Private Classes

* `restic::package`: Install restic packages
* `restic::reload`: Reload systemd via `systemctl daemon-reload`

### Defined types

#### Public Defined types

* [`restic::repository`](#restic--repository): Configure a Restic service to backup/forget/restore data.
* [`restic::repository::post_command`](#restic--repository--post_command): Define command(s) to be run after a restic command
* [`restic::repository::pre_command`](#restic--repository--pre_command): Define command(s) to be run before a restic command

#### Private Defined types

* `restic::service`: Configure a restic service

### Data types

* [`Restic::Forget`](#Restic--Forget): All valid forget parameter
* [`Restic::Path`](#Restic--Path): Valid path parameter
* [`Restic::Repositories`](#Restic--Repositories): A data hash with restic backup configuration
* [`Restic::Repository::Type`](#Restic--Repository--Type): All valid repository types

## Classes

### <a name="restic"></a>`restic`

Module to manage restic repositories via systemd service/timer.

#### Parameters

The following parameters are available in the `restic` class:

* [`package_ensure`](#-restic--package_ensure)
* [`package_manage`](#-restic--package_manage)
* [`package_name`](#-restic--package_name)
* [`package_version`](#-restic--package_version)
* [`checksum`](#-restic--checksum)
* [`install_method`](#-restic--install_method)
* [`repositories`](#-restic--repositories)
* [`backup_flags`](#-restic--backup_flags)
* [`backup_path`](#-restic--backup_path)
* [`backup_pre_cmd`](#-restic--backup_pre_cmd)
* [`backup_post_cmd`](#-restic--backup_post_cmd)
* [`backup_timer`](#-restic--backup_timer)
* [`backup_exit3_success`](#-restic--backup_exit3_success)
* [`binary`](#-restic--binary)
* [`bucket`](#-restic--bucket)
* [`enable_backup`](#-restic--enable_backup)
* [`enable_forget`](#-restic--enable_forget)
* [`enable_restore`](#-restic--enable_restore)
* [`forget`](#-restic--forget)
* [`forget_flags`](#-restic--forget_flags)
* [`forget_pre_cmd`](#-restic--forget_pre_cmd)
* [`forget_post_cmd`](#-restic--forget_post_cmd)
* [`forget_timer`](#-restic--forget_timer)
* [`global_flags`](#-restic--global_flags)
* [`group`](#-restic--group)
* [`host`](#-restic--host)
* [`id`](#-restic--id)
* [`init_repo`](#-restic--init_repo)
* [`key`](#-restic--key)
* [`password`](#-restic--password)
* [`prune`](#-restic--prune)
* [`restore_flags`](#-restic--restore_flags)
* [`restore_path`](#-restic--restore_path)
* [`restore_pre_cmd`](#-restic--restore_pre_cmd)
* [`restore_post_cmd`](#-restic--restore_post_cmd)
* [`restore_snapshot`](#-restic--restore_snapshot)
* [`restore_timer`](#-restic--restore_timer)
* [`type`](#-restic--type)
* [`user`](#-restic--user)

##### <a name="-restic--package_ensure"></a>`package_ensure`

Data type: `String`

Version for Restic to be installed

Default value: `'present'`

##### <a name="-restic--package_manage"></a>`package_manage`

Data type: `Boolean`

Enable Restic package management

Default value: `true`

##### <a name="-restic--package_name"></a>`package_name`

Data type: `String`

Name for Restic package

Default value: `'restic'`

##### <a name="-restic--package_version"></a>`package_version`

Data type: `Optional[String[1]]`

Restic version when installing with the `url` method.

Default value: `undef`

##### <a name="-restic--checksum"></a>`checksum`

Data type: `Optional[String[1]]`

Checksum of the Restic archive. Only applicable when using `install_method = 'url'`.

Default value: `undef`

##### <a name="-restic--install_method"></a>`install_method`

Data type: `Enum['package', 'url']`

Install method to use.

Default value: `'package'`

##### <a name="-restic--repositories"></a>`repositories`

Data type: `Restic::Repositories`

Hash of repositoriries

Default value: `{}`

##### <a name="-restic--backup_flags"></a>`backup_flags`

Data type: `Variant[Array[String[1]],String[1]]`

Default flags for `restic backup <flags>`. See `restic backup --help`

Default value: `[]`

##### <a name="-restic--backup_path"></a>`backup_path`

Data type: `Optional[Restic::Path]`

Default directory to backed up

Default value: `undef`

##### <a name="-restic--backup_pre_cmd"></a>`backup_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run before `restic backup`

Default value: `undef`

##### <a name="-restic--backup_post_cmd"></a>`backup_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run after `restic backup`

Default value: `undef`

##### <a name="-restic--backup_timer"></a>`backup_timer`

Data type: `Optional[String[1]]`

Default systemd timer for backup see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: `undef`

##### <a name="-restic--backup_exit3_success"></a>`backup_exit3_success`

Data type: `Boolean`

Consider restic's exit code 3 as success. https://restic.readthedocs.io/en/latest/040_backup.html#exit-status-codes

Default value: `false`

##### <a name="-restic--binary"></a>`binary`

Data type: `Stdlib::Absolutepath`

Default path to the Restic binary

Default value: `'/usr/bin/restic'`

##### <a name="-restic--bucket"></a>`bucket`

Data type: `Optional[String]`

Default name for the Restic repository

Default value: `undef`

##### <a name="-restic--enable_backup"></a>`enable_backup`

Data type: `Boolean`

Default enable the backup service

Default value: `true`

##### <a name="-restic--enable_forget"></a>`enable_forget`

Data type: `Boolean`

Default enable the forget service

Default value: `false`

##### <a name="-restic--enable_restore"></a>`enable_restore`

Data type: `Boolean`

Default enable the restore service

Default value: `false`

##### <a name="-restic--forget"></a>`forget`

Data type: `Restic::Forget`

Default hash with `keep-*` => `value` to configure forget flags

Default value: `{}`

##### <a name="-restic--forget_flags"></a>`forget_flags`

Data type: `Variant[Array[String[1]],String[1]]`

Default flags for `restic forget <flags>`. See `restic forget --help`

Default value: `[]`

##### <a name="-restic--forget_pre_cmd"></a>`forget_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run before `restic forget`

Default value: `undef`

##### <a name="-restic--forget_post_cmd"></a>`forget_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run after `restic forget`

Default value: `undef`

##### <a name="-restic--forget_timer"></a>`forget_timer`

Data type: `Optional[String[1]]`

Default systemd timer for forget see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: `undef`

##### <a name="-restic--global_flags"></a>`global_flags`

Data type: `Variant[Array[String[1]],String[1]]`

Default global flags for `restic <flags>`. See `restic --help`

Default value: `[]`

##### <a name="-restic--group"></a>`group`

Data type: `String`

Default group for systemd services

Default value: `'root'`

##### <a name="-restic--host"></a>`host`

Data type: `Optional[Variant[Sensitive[String],String]]`

Default hostname for the Restic repository

Default value: `undef`

##### <a name="-restic--id"></a>`id`

Data type: `Optional[Variant[Sensitive[String],String]]`

Default S3 storage id for an S3 bucket

Default value: `undef`

##### <a name="-restic--init_repo"></a>`init_repo`

Data type: `Boolean`

Default enable the initialization of the repository

Default value: `true`

##### <a name="-restic--key"></a>`key`

Data type: `Optional[Variant[Sensitive[String],String]]`

Default S3 storage key for an S3 bucket

Default value: `undef`

##### <a name="-restic--password"></a>`password`

Data type: `Optional[Variant[Sensitive[String],String]]`

Default encryption password for the Restic repository

Default value: `undef`

##### <a name="-restic--prune"></a>`prune`

Data type: `Boolean`

Default enable `--prune` flag for `restic forget`

Default value: `false`

##### <a name="-restic--restore_flags"></a>`restore_flags`

Data type: `Variant[Array[String[1]],String[1]]`

Default flags for `restic restore <flags>`. See `restic restore --help`

Default value: `[]`

##### <a name="-restic--restore_path"></a>`restore_path`

Data type: `Optional[Stdlib::Absolutepath]`

Default directory used to restore a backup

Default value: `undef`

##### <a name="-restic--restore_pre_cmd"></a>`restore_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

command to run before execute restore
Default command to run before `restic restore`

Default value: `undef`

##### <a name="-restic--restore_post_cmd"></a>`restore_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

command to run after execute restore
Default command to run after `restic restore`

Default value: `undef`

##### <a name="-restic--restore_snapshot"></a>`restore_snapshot`

Data type: `String[1]`

Default Restic snapshot id used by the restore

Default value: `'latest'`

##### <a name="-restic--restore_timer"></a>`restore_timer`

Data type: `Optional[String[1]]`

Default systemd timer for restore see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: `undef`

##### <a name="-restic--type"></a>`type`

Data type: `Restic::Repository::Type`

Default name for the Restic repository. Only S3 supported

Default value: `'s3'`

##### <a name="-restic--user"></a>`user`

Data type: `String[1]`

Default user for systemd services

Default value: `'root'`

## Defined types

### <a name="restic--repository"></a>`restic::repository`

Configure a Restic service to backup/forget/restore data.

#### Parameters

The following parameters are available in the `restic::repository` defined type:

* [`backup_flags`](#-restic--repository--backup_flags)
* [`backup_path`](#-restic--repository--backup_path)
* [`backup_pre_cmd`](#-restic--repository--backup_pre_cmd)
* [`backup_post_cmd`](#-restic--repository--backup_post_cmd)
* [`backup_timer`](#-restic--repository--backup_timer)
* [`backup_exit3_success`](#-restic--repository--backup_exit3_success)
* [`binary`](#-restic--repository--binary)
* [`bucket`](#-restic--repository--bucket)
* [`enable_backup`](#-restic--repository--enable_backup)
* [`enable_forget`](#-restic--repository--enable_forget)
* [`enable_restore`](#-restic--repository--enable_restore)
* [`forget`](#-restic--repository--forget)
* [`forget_flags`](#-restic--repository--forget_flags)
* [`forget_pre_cmd`](#-restic--repository--forget_pre_cmd)
* [`forget_post_cmd`](#-restic--repository--forget_post_cmd)
* [`forget_timer`](#-restic--repository--forget_timer)
* [`global_flags`](#-restic--repository--global_flags)
* [`group`](#-restic--repository--group)
* [`host`](#-restic--repository--host)
* [`id`](#-restic--repository--id)
* [`init_repo`](#-restic--repository--init_repo)
* [`key`](#-restic--repository--key)
* [`password`](#-restic--repository--password)
* [`prune`](#-restic--repository--prune)
* [`restore_flags`](#-restic--repository--restore_flags)
* [`restore_path`](#-restic--repository--restore_path)
* [`restore_pre_cmd`](#-restic--repository--restore_pre_cmd)
* [`restore_post_cmd`](#-restic--repository--restore_post_cmd)
* [`restore_snapshot`](#-restic--repository--restore_snapshot)
* [`restore_timer`](#-restic--repository--restore_timer)
* [`type`](#-restic--repository--type)
* [`user`](#-restic--repository--user)

##### <a name="-restic--repository--backup_flags"></a>`backup_flags`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default flags for `restic backup <flags>`. See `restic backup --help`

Default value: `undef`

##### <a name="-restic--repository--backup_path"></a>`backup_path`

Data type: `Optional[Restic::Path]`

Default directory to backed up

Default value: `undef`

##### <a name="-restic--repository--backup_pre_cmd"></a>`backup_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run before `restic backup`

Default value: `undef`

##### <a name="-restic--repository--backup_post_cmd"></a>`backup_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run after `restic backup`

Default value: `undef`

##### <a name="-restic--repository--backup_timer"></a>`backup_timer`

Data type: `Optional[String[1]]`

Default systemd timer for backup see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: `undef`

##### <a name="-restic--repository--backup_exit3_success"></a>`backup_exit3_success`

Data type: `Optional[Boolean]`

Consider restic's exit code 3 as success. https://restic.readthedocs.io/en/latest/040_backup.html#exit-status-codes

Default value: `undef`

##### <a name="-restic--repository--binary"></a>`binary`

Data type: `Optional[Stdlib::Absolutepath]`

Default path to the Restic binary

Default value: `undef`

##### <a name="-restic--repository--bucket"></a>`bucket`

Data type: `Optional[String]`

Default name for the Restic repository

Default value: `undef`

##### <a name="-restic--repository--enable_backup"></a>`enable_backup`

Data type: `Optional[Boolean]`

Default enable the backup service

Default value: `undef`

##### <a name="-restic--repository--enable_forget"></a>`enable_forget`

Data type: `Optional[Boolean]`

Default enable the forget service

Default value: `undef`

##### <a name="-restic--repository--enable_restore"></a>`enable_restore`

Data type: `Optional[Boolean]`

Default enable the restore service

Default value: `undef`

##### <a name="-restic--repository--forget"></a>`forget`

Data type: `Optional[Restic::Forget]`

Default hash with `keep-*` => `value` to configure forget flags

Default value: `undef`

##### <a name="-restic--repository--forget_flags"></a>`forget_flags`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default flags for `restic forget <flags>`. See `restic forget --help`

Default value: `undef`

##### <a name="-restic--repository--forget_pre_cmd"></a>`forget_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run before `restic forget`

Default value: `undef`

##### <a name="-restic--repository--forget_post_cmd"></a>`forget_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default command to run after `restic forget`

Default value: `undef`

##### <a name="-restic--repository--forget_timer"></a>`forget_timer`

Data type: `Optional[String[1]]`

Default systemd timer for forget see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: `undef`

##### <a name="-restic--repository--global_flags"></a>`global_flags`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default global flags for `restic <flags>`. See `restic --help`

Default value: `undef`

##### <a name="-restic--repository--group"></a>`group`

Data type: `Optional[String]`

Default group for systemd services

Default value: `undef`

##### <a name="-restic--repository--host"></a>`host`

Data type: `Optional[Variant[Sensitive[String],String]]`

Default hostname for the Restic repository

Default value: `undef`

##### <a name="-restic--repository--id"></a>`id`

Data type: `Optional[Variant[Sensitive[String],String]]`

Default S3 storage id for an S3 bucket

Default value: `undef`

##### <a name="-restic--repository--init_repo"></a>`init_repo`

Data type: `Optional[Boolean]`

Default enable the initialization of the repository

Default value: `undef`

##### <a name="-restic--repository--key"></a>`key`

Data type: `Optional[Variant[Sensitive[String],String]]`

Default S3 storage key for an S3 bucket

Default value: `undef`

##### <a name="-restic--repository--password"></a>`password`

Data type: `Optional[Variant[Sensitive[String],String]]`

Default encryption password for the Restic repository

Default value: `undef`

##### <a name="-restic--repository--prune"></a>`prune`

Data type: `Optional[Boolean]`

Default enable `--prune` flag for `restic forget`

Default value: `undef`

##### <a name="-restic--repository--restore_flags"></a>`restore_flags`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

Default flags for `restic restore <flags>`. See `restic restore --help`

Default value: `undef`

##### <a name="-restic--repository--restore_path"></a>`restore_path`

Data type: `Optional[Stdlib::Absolutepath]`

Default directory used to restore a backup

Default value: `undef`

##### <a name="-restic--repository--restore_pre_cmd"></a>`restore_pre_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

command to run before execute restore
Default command to run before `restic restore`

Default value: `undef`

##### <a name="-restic--repository--restore_post_cmd"></a>`restore_post_cmd`

Data type: `Optional[Variant[Array[String[1]],String[1]]]`

command to run after execute restore
Default command to run after `restic restore`

Default value: `undef`

##### <a name="-restic--repository--restore_snapshot"></a>`restore_snapshot`

Data type: `Optional[String[1]]`

Default Restic snapshot id used by the restore

Default value: `undef`

##### <a name="-restic--repository--restore_timer"></a>`restore_timer`

Data type: `Optional[String[1]]`

Default systemd timer for restore see: https://wiki.archlinux.de/title/Systemd/Timers

Default value: `undef`

##### <a name="-restic--repository--type"></a>`type`

Data type: `Optional[Restic::Repository::Type]`

Default name for the Restic repository. Only S3 supported

Default value: `undef`

##### <a name="-restic--repository--user"></a>`user`

Data type: `Optional[String[1]]`

Default user for systemd services

Default value: `undef`

### <a name="restic--repository--post_command"></a>`restic::repository::post_command`

Define command(s) to be run after a restic command

#### Examples

##### Define a command to be run after the backup

```puppet
restic::repository::pre_command { 'mysql':
  command => 'rm -rf /opt/xtrabackup',
}
```

#### Parameters

The following parameters are available in the `restic::repository::post_command` defined type:

* [`command`](#-restic--repository--post_command--command)
* [`repository_title`](#-restic--repository--post_command--repository_title)
* [`restic_command`](#-restic--repository--post_command--restic_command)
* [`allow_fail`](#-restic--repository--post_command--allow_fail)
* [`order`](#-restic--repository--post_command--order)

##### <a name="-restic--repository--post_command--command"></a>`command`

Data type: `Variant[Array[String[1]],String[1]]`

Command to run.

##### <a name="-restic--repository--post_command--repository_title"></a>`repository_title`

Data type: `String[1]`

restic::repository title where this command should be add to.

Default value: `$title`

##### <a name="-restic--repository--post_command--restic_command"></a>`restic_command`

Data type: `Enum['backup', 'forget', 'restore']`

After which restic command this command should be run.

Default value: `'backup'`

##### <a name="-restic--repository--post_command--allow_fail"></a>`allow_fail`

Data type: `Boolean`

If an error of this commands should be allowed.

Default value: `false`

##### <a name="-restic--repository--post_command--order"></a>`order`

Data type: `Integer[26]`

Order of Commands. Helpful if you have multiple.

Default value: `26`

### <a name="restic--repository--pre_command"></a>`restic::repository::pre_command`

Define command(s) to be run before a restic command

#### Examples

##### Define a command to be run before the backup

```puppet
restic::repository::pre_command { 'mysql':
  command => 'xtrabackup --backup --target-dir=/opt/xtrabackup',
}
```

#### Parameters

The following parameters are available in the `restic::repository::pre_command` defined type:

* [`command`](#-restic--repository--pre_command--command)
* [`repository_title`](#-restic--repository--pre_command--repository_title)
* [`restic_command`](#-restic--repository--pre_command--restic_command)
* [`allow_fail`](#-restic--repository--pre_command--allow_fail)
* [`order`](#-restic--repository--pre_command--order)

##### <a name="-restic--repository--pre_command--command"></a>`command`

Data type: `Variant[Array[String[1]],String[1]]`

Command to run.

##### <a name="-restic--repository--pre_command--repository_title"></a>`repository_title`

Data type: `String[1]`

restic::repository title where this command should be add to.

Default value: `$title`

##### <a name="-restic--repository--pre_command--restic_command"></a>`restic_command`

Data type: `Enum['backup', 'forget', 'restore']`

Before which restic command this command should be run.

Default value: `'backup'`

##### <a name="-restic--repository--pre_command--allow_fail"></a>`allow_fail`

Data type: `Boolean`

If an error of this commands should be allowed.

Default value: `false`

##### <a name="-restic--repository--pre_command--order"></a>`order`

Data type: `Integer[11,24]`

Order of Commands. Helpful if you have multiple.

Default value: `11`

## Data types

### <a name="Restic--Forget"></a>`Restic::Forget`

All valid forget parameter

Alias of `Hash[Enum['keep-last','keep-hourly','keep-daily','keep-weekly','keep-monthly','keep-yearly','keep-within','keep-within-hourly','keep-within-daily','keep-within-weekly','keep-within-monthly','keep-within-yearly','keep-tag'], Variant[Integer[1],String[1]]]`

### <a name="Restic--Path"></a>`Restic::Path`

Valid path parameter

Alias of `Variant[Stdlib::Absolutepath, Array[Stdlib::Absolutepath]]`

### <a name="Restic--Repositories"></a>`Restic::Repositories`

A data hash with restic backup configuration

Alias of

```puppet
Hash[String[1], Struct[
    {
      backup_exit3_success => Optional[Boolean],
      backup_flags         => Optional[Variant[Array[String[1]],String[1]]],
      backup_path          => Optional[Restic::Path],
      backup_post_cmd      => Optional[Variant[Array[String[1]],String[1]]],
      backup_pre_cmd       => Optional[Variant[Array[String[1]],String[1]]],
      backup_timer         => Optional[String[1]],
      binary               => Optional[Stdlib::Absolutepath],
      bucket               => Optional[String],
      enable_backup        => Optional[Boolean],
      enable_forget        => Optional[Boolean],
      enable_restore       => Optional[Boolean],
      forget               => Optional[Restic::Forget],
      forget_flags         => Optional[Variant[Array[String[1]],String[1]]],
      forget_post_cmd      => Optional[Variant[Array[String[1]],String[1]]],
      forget_pre_cmd       => Optional[Variant[Array[String[1]],String[1]]],
      forget_timer         => Optional[String[1]],
      global_flags         => Optional[Variant[Array[String[1]],String[1]]],
      group                => Optional[String],
      host                 => Optional[Variant[Sensitive[String],String]],
      id                   => Optional[Variant[Sensitive[String],String]],
      init_repo            => Optional[Boolean],
      key                  => Optional[Variant[Sensitive[String],String]],
      password             => Optional[Variant[Sensitive[String],String]],
      prune                => Optional[Boolean],
      restore_flags        => Optional[Variant[Array[String[1]],String[1]]],
      restore_path         => Optional[Stdlib::Absolutepath],
      restore_post_cmd     => Optional[Variant[Array[String[1]],String[1]]],
      restore_pre_cmd      => Optional[Variant[Array[String[1]],String[1]]],
      restore_snapshot     => Optional[String[1]],
      restore_timer        => Optional[String[1]],
      type                 => Optional[Restic::Repository::Type],
      user                 => Optional[String[1]],
    }
  ]]
```

### <a name="Restic--Repository--Type"></a>`Restic::Repository::Type`

All valid repository types

Alias of `Enum['rest', 's3']`

